summaryrefslogtreecommitdiff
path: root/internal/models/atom.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/models/atom.go')
-rw-r--r--internal/models/atom.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/internal/models/atom.go b/internal/models/atom.go
index 9c519ba..3745917 100644
--- a/internal/models/atom.go
+++ b/internal/models/atom.go
@@ -57,15 +57,15 @@ func (a *Atom) ComputeUIFields() {
tz := config.GetDisplayTimezone()
now := config.Now()
today := time.Date(now.Year(), now.Month(), now.Day(), 0, 0, 0, 0, tz)
- tomorrow := today.AddDate(0, 0, 1)
// Check if overdue (due date is before today)
dueInTZ := a.DueDate.In(tz)
dueDay := time.Date(dueInTZ.Year(), dueInTZ.Month(), dueInTZ.Day(), 0, 0, 0, 0, tz)
a.IsOverdue = dueDay.Before(today)
- // Check if future (due date is after today)
- a.IsFuture = !dueDay.Before(tomorrow)
+ // Check if future (due date is 7+ days out — collapse in tasks tab)
+ sevenDaysOut := today.AddDate(0, 0, 7)
+ a.IsFuture = !dueDay.Before(sevenDaysOut)
// Check if has set time (not midnight)
a.HasSetTime = dueInTZ.Hour() != 0 || dueInTZ.Minute() != 0